@@ -12,6 +12,7 @@ from ecowitt2mqtt.const import (
     ENV_CONFIG,
     ENV_DEFAULT_BATTERY_STRATEGY,
     ENV_DIAGNOSTICS,
+    ENV_DISABLE_CALCULATED_DATA,
     ENV_ENDPOINT,
     ENV_HASS_DISCOVERY,
     ENV_HASS_DISCOVERY_PREFIX,
@@ -20,6 +21,7 @@ from ecowitt2mqtt.const import (
     ENV_MQTT_BROKER,
     ENV_MQTT_PASSWORD,
     ENV_MQTT_PORT,
+    ENV_MQTT_RETAIN,
     ENV_MQTT_TLS,
     ENV_MQTT_TOPIC,
     ENV_MQTT_USERNAME,
@@ -95,6 +97,12 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals
         envvar=[ENV_DIAGNOSTICS],
         help="Output diagnostics.",
     ),
+    disable_calculated_data: bool = typer.Option(
+        False,
+        "--disable-calculated-data",
+        envvar=[ENV_DISABLE_CALCULATED_DATA],
+        help="Disable the output of calculated sensors.",
+    ),
     endpoint: str = typer.Option(
         DEFAULT_ENDPOINT,
         "--endpoint",
@@ -147,6 +155,12 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals
         envvar=[ENV_MQTT_PORT, LEGACY_ENV_MQTT_PORT],
         help="The listenting port of the MQTT broker.",
     ),
+    mqtt_retain: bool = typer.Option(
+        False,
+        "--mqtt-retain",
+        envvar=[ENV_MQTT_RETAIN],
+        help="Instruct the MQTT broker to retain messages.",
+    ),
     mqtt_tls: bool = typer.Option(
         False,
         "--mqtt-tls",
