@@ -4,7 +4,7 @@ from typing import Final
 
 from ecowitt2mqtt.helpers.typing import UnitSystemType
 
-__version__ = "2022.07.3"
+__version__ = "2022.07.5"
 
 
 LOGGER = logging.getLogger(__package__)
@@ -14,6 +14,7 @@ CONF_BATTERY_OVERRIDES: Final = "battery_override"
 CONF_CONFIG: Final = "config"
 CONF_DEFAULT_BATTERY_STRATEGY: Final = "default_battery_strategy"
 CONF_DIAGNOSTICS: Final = "diagnostics"
+CONF_DISABLE_CALCULATED_DATA: Final = "disable_calculated_data"
 CONF_ENDPOINT: Final = "endpoint"
 CONF_HASS_DISCOVERY: Final = "hass_discovery"
 CONF_HASS_DISCOVERY_PREFIX: Final = "hass_discovery_prefix"
@@ -22,6 +23,7 @@ CONF_INPUT_UNIT_SYSTEM: Final = "input_unit_system"
 CONF_MQTT_BROKER: Final = "mqtt_broker"
 CONF_MQTT_PASSWORD: Final = "mqtt_password"
 CONF_MQTT_PORT: Final = "mqtt_port"
+CONF_MQTT_RETAIN: Final = "mqtt_retain"
 CONF_MQTT_TLS: Final = "mqtt_tls"
 CONF_MQTT_TOPIC: Final = "mqtt_topic"
 CONF_MQTT_USERNAME: Final = "mqtt_username"
@@ -119,6 +121,7 @@ ENV_BATTERY_OVERRIDE: Final = "ECOWITT2MQTT_BATTERY_OVERRIDE"
 ENV_CONFIG: Final = "ECOWITT2MQTT_CONFIG"
 ENV_DEFAULT_BATTERY_STRATEGY: Final = "ECOWITT2MQTT_DEFAULT_BATTERY_STRATEGY"
 ENV_DIAGNOSTICS: Final = "ECOWITT2MQTT_DIAGNOSTICS"
+ENV_DISABLE_CALCULATED_DATA: Final = "ECOWITT2MQTT_DISABLE_CALCULATED_DATA"
 ENV_ENDPOINT: Final = "ECOWITT2MQTT_ENDPOINT"
 ENV_HASS_DISCOVERY: Final = "ECOWITT2MQTT_HASS_DISCOVERY"
 ENV_HASS_DISCOVERY_PREFIX: Final = "ECOWITT2MQTT_HASS_DISCOVERY_PREFIX"
@@ -127,6 +130,7 @@ ENV_INPUT_UNIT_SYSTEM: Final = "ECOWITT2MQTT_INPUT_UNIT_SYSTEM"
 ENV_MQTT_BROKER: Final = "ECOWITT2MQTT_MQTT_BROKER"
 ENV_MQTT_PASSWORD: Final = "ECOWITT2MQTT_MQTT_PASSWORD"
 ENV_MQTT_PORT: Final = "ECOWITT2MQTT_MQTT_PORT"
+ENV_MQTT_RETAIN: Final = "ECOWITT2MQTT_MQTT_RETAIN"
 ENV_MQTT_TLS: Final = "ECOWITT2MQTT_MQTT_TLS"
 ENV_MQTT_TOPIC: Final = "ECOWITT2MQTT_MQTT_TOPIC"
 ENV_MQTT_USERNAME: Final = "ECOWITT2MQTT_MQTT_USERNAME"
